pub fn empty_range() -> RangeInclusive<isize> ⓘExpand description
The empty RangeInclusive<isize>, for a grading support with no elements.
start > end, so it yields nothing and contains is always false.
pub fn empty_range() -> RangeInclusive<isize> ⓘThe empty RangeInclusive<isize>, for a grading support with no elements.
start > end, so it yields nothing and contains is always false.