pub struct AsKey<T>(pub T)
where
T: IndexType;Expand description
Wraps an arbitrary element T so it can be used as an LcKey.
Used to build the free module over any T: IndexType.
Tuple Fields
0: TTrait Implementations
impl<T> Eq for AsKey<T>
impl<T> LcKey for AsKey<T>where
T: IndexType,
Sourceimpl<T> Ord for AsKey<T>
impl<T> Ord for AsKey<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T> PartialOrd for AsKey<T>where
T: IndexType + PartialOrd,
impl<T> PartialOrd for AsKey<T>where
T: IndexType + PartialOrd,
impl<T> StructuralPartialEq for AsKey<T>