table

Function table 

pub fn table<S, I, J, I1, I2, D, F>(
    head: S,
    rows: I1,
    cols: I2,
    entry: F,
) -> String
where S: Display, I: Display, J: Display, I1: IntoIterator<Item = I>, I2: IntoIterator<Item = J>, D: Display, F: Fn(&I, &J) -> D,
Render a 2D table with the given header label, row keys, column keys, and a function producing each cell entry. Backed by prettytable.