SyncCounter: a thread-safe counter used to label objects during a build.
Structs
- Sync
Counter - A thread-safe
usizecounter, backed byAtomicUsize.
SyncCounter: a thread-safe counter used to label objects during a build.
usize counter, backed by AtomicUsize.